@@ -4,6 +4,12 @@ TEST="Test apci table against invalid IORT"
 NAME=test-0001.sh
 TMPLOG=$TMP/iort.log.$$
 
+$FWTS --show-tests | grep IORT > /dev/null
+if [ $? -eq 1 ]; then
+	echo SKIP: $TEST, $NAME
+	exit 77
+fi
+
 $FWTS --log-format="%line %owner " -w 80 --dumpfile=$FWTSTESTDIR/iort-0001/acpidump-0002.log iort - | cut -c7- | grep "^iort" > $TMPLOG
 diff $TMPLOG $FWTSTESTDIR/iort-0001/iort-0002.log >> $FAILURE_LOG
 ret=$?
