@@ -23,7 +23,7 @@
 # Get fwts sources, strip out .git directory, add in necessary debian packaging
 # files, build source package ready for upload.
 #
-RELEASES="bionic focal jammy kinetic lunar"
+RELEASES="bionic focal jammy kinetic lunar mantic"
 REPO=git://kernel.ubuntu.com/hwe/fwts.git
 RELEASE_TAR_URL=http://fwts.ubuntu.com/release
 FWTS=fwts
@@ -123,7 +123,7 @@ mk_package()
 	#
 	sed "s/) $deb_release/$suffix) $rel;/" debian/changelog > debian/changelog.new
 	mv debian/changelog.new debian/changelog
-	
+
   	echo 'y' | debuild -S
 	rm -rf $FWTS
 	popd >& /dev/null
