@@ -35,7 +35,7 @@
 #include <limits.h>
 #include <fcntl.h>
 
-#define DMI_VERSION			(0x0350)
+#define DMI_VERSION			(0x0360)
 #define VERSION_MAJOR(v)		((v) >> 8)
 #define VERSION_MINOR(v)		((v) & 0xff)
 
@@ -57,6 +57,7 @@
 #define DMI_RESERVED_BIT_USED		"DMIReservedBitUsed"
 #define DMI_RESERVED_OFFSET_NONZERO	"DMIReservedOffsetNonZero"
 
+#define GET_UINT8(x) (uint8_t)(*(const uint8_t *)(x))
 #define GET_UINT16(x) (uint16_t)(*(const uint16_t *)(x))
 #define GET_UINT32(x) (uint32_t)(*(const uint32_t *)(x))
 #define GET_UINT64(x) (uint64_t)(*(const uint64_t *)(x))
@@ -116,6 +117,10 @@ static const fwts_dmi_pattern dmi_patterns[] = {
 	{ "DMISerialNumber",	"Serial Number",	"01234567890" },
 	{ "DMISerialNumber",	"Serial Number",	"012345678900" },
 	{ "DMISerialNumber",	"Serial Number",	"0123456789000" },
+	{ "DMISerialNumber",	"Serial Number",	"1234567" },
+	{ "DMISerialNumber",	"Serial Number",	"12345678" },
+	{ "DMISerialNumber",	"Serial Number",	"123456789" },
+	{ "DMISerialNumber",	"Serial Number",	"1234567890" },
 	{ "DMISerialNumber",	"Serial Number",	"System Serial Number" },
 	{ "DMISerialNumber",	"Serial Number",	"MB-1234567890" },
 	{ "DMISerialNumber",	"Serial Number",	"NB-1234567890" },
@@ -153,6 +158,7 @@ static const fwts_dmi_pattern dmi_patterns[] = {
 	{ "DMISerialNumber",	"Serial Number",	"To Be Filled By O.E.M." },
 	{ "DMISerialNumber",	"Serial Number",	"Unknow" },
 	{ "DMISerialNumber",	"Serial Number",	"Unknown" },
+	{ "DMISerialNumber",	"Serial Number",	"Unspecified System Serial Number" },
 	{ "DMISerialNumber",	"Serial Number",	"XXXXXXXXXXXX" },
 	{ "DMISerialNumber",	"Serial Number",	"XXXXXXXXXXX" },
 	{ "DMISerialNumber",	"Serial Number",	"XXXXXXXXXX" },
@@ -1297,7 +1303,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			/* new fields in spec 3.11 */
 			if (hdr->length < 0x1a)
 				break;
-			dmi_reserved_bits_check(fw, table, addr, "Extended BIOS ROM Size", hdr, sizeof(uint16_t), 0x18, 14, 15);
+			dmi_reserved_bits_check(fw, table, addr, "Extended BIOS ROM Size", hdr, sizeof(uint16_t), 0x18, 15, 15);
 			break;
 
 		case 1: /* 7.2 */
@@ -1391,9 +1397,20 @@ static void dmicheck_entry(fwts_framework *fw,
 				break;
 			dmi_str_check(fw, table, addr, "Socket Designation", hdr, 0x4);
 			dmi_min_max_uint8_check(fw, table, addr, "Processor Type", hdr, 0x5, 0x1, 0x6);
+			dmi_min_max_uint8_check(fw, table, addr, "Processor Family", hdr, 0x6, 0x1, 0xfe);
 			dmi_str_check(fw, table, addr, "Processor Manufacturer", hdr, 0x7);
 			dmi_str_check(fw, table, addr, "Processor Version", hdr, 0x10);
-			dmi_min_max_uint8_check(fw, table, addr, "Upgrade", hdr, 0x19, 0x1, 0x3f);
+			if (((GET_UINT8(data + 0x18) & 0x07) == 0x5) || ((GET_UINT8(data + 0x18) & 0x07) == 0x6))
+				fwts_failed(fw, LOG_LEVEL_HIGH, DMI_VALUE_OUT_OF_RANGE,
+					"Out of range value 0x%2.2" PRIx8 " "
+					"bits 0..2 set to illegal value 0x5 or 0x6 "
+					"while accessing entry '%s' @ 0x%8.8" PRIx32
+					", field '%s', offset 0x%2.2x",
+					GET_UINT8(data + 0x18),
+					table, addr, "Status", 0x18);
+			dmi_reserved_bits_check(fw, table, addr, "Status", hdr, sizeof(uint8_t), 0x18, 3, 5);
+			dmi_reserved_bits_check(fw, table, addr, "Status", hdr, sizeof(uint8_t), 0x18, 7, 7);
+			dmi_min_max_uint8_check(fw, table, addr, "Processor Upgrade", hdr, 0x19, 0x1, 0x48);
 			if (hdr->length < 0x23)
 				break;
 			dmi_str_check(fw, table, addr, "Serial Number", hdr, 0x20);
@@ -1401,12 +1418,19 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_str_check(fw, table, addr, "Part Number", hdr, 0x22);
 			if (hdr->length < 0x28)
 				break;
+			dmi_reserved_bits_check(fw, table, addr, "Processor Characteristics", hdr, sizeof(uint16_t), 0x26, 0, 0);
 			dmi_reserved_bits_check(fw, table, addr, "Processor Characteristics", hdr, sizeof(uint16_t), 0x26, 10, 15);
+			if (hdr->length < 0x2a)
+				break;
+			dmi_min_max_uint16_check(fw, table, addr, "Processor Family 2", hdr, 0x28, 0x1, 0xfffd);
 			if (hdr->length < 0x30)
 				break;
 			dmi_min_max_uint16_check(fw, table, addr, "Core Count 2", hdr, 0x2a, 0, 0xfffe);
 			dmi_min_max_uint16_check(fw, table, addr, "Core Enabled 2", hdr, 0x2c, 0, 0xfffe);
-			dmi_min_max_uint16_check(fw, table, addr, "Thread Enabled 2", hdr, 0x2e, 0, 0xfffe);
+			dmi_min_max_uint16_check(fw, table, addr, "Thread Count 2", hdr, 0x2e, 0, 0xfffe);
+			if (hdr->length < 0x32)
+				break;
+			dmi_min_max_uint16_check(fw, table, addr, "Thread Enabled", hdr, 0x30, 0, 0xfffe);
 			break;
 
 		case 5: /* 7.6 (Type 5 is obsolete) */
@@ -1432,7 +1456,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_str_check(fw, table, addr, "Socket Designation", hdr, 0x4);
 			if (((GET_UINT16(data + 0x05) >> 5) & 0x0003) == 0x2)
 				fwts_failed(fw, LOG_LEVEL_HIGH, DMI_VALUE_OUT_OF_RANGE,
-					"Out of range value %x4.4" PRIx16 " "
+					"Out of range value 0x%4.4" PRIx16 " "
 					"bits 5..6 set to illegal value 0x2, only allowed"
 					"0x0, 0x1, 0x3 while accessing entry '%s' @ "
 					"0x%8.8" PRIx32 ", field '%s', offset 0x%2.2x",
@@ -1502,10 +1526,10 @@ static void dmicheck_entry(fwts_framework *fw,
 						data[0x10], table, addr, "Device/Function Number", 0x10);
 			}
 
-			if (hdr->length < (0x17 + 5 * data[0x12]))
+			if (hdr->length < (0x18 + 5 * data[0x12]))
 				break;
 
-			dmi_min_max_uint8_check(fw, table, addr, "Slot Height", hdr, (0x17 + 5 * data[0x12]), 0, 0x6);
+			dmi_min_max_uint8_check(fw, table, addr, "Slot Height", hdr, (0x17 + 5 * data[0x12]), 0, 0x4);
 
 			break;
 
@@ -1635,7 +1659,9 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_min_max_uint8_check(fw, table, addr, "Form Factor", hdr, 0xe, 0x1, 0x10);
 			dmi_str_check(fw, table, addr, "Locator", hdr, 0x10);
 			dmi_str_check(fw, table, addr, "Bank Locator", hdr, 0x11);
-			dmi_min_max_uint8_check(fw, table, addr, "Memory Type", hdr, 0x12, 0x1, 0x23);
+			fwts_dmi_value_range t17_ranges[] = {{0x1, 0x14}, {0x18, 0x24}};
+			dmi_ranges_uint8_check(fw, table, addr, "Memory Type", hdr, 0x12, t17_ranges);
+			dmi_reserved_bits_check(fw, table, addr, "Type Detail", hdr, sizeof(uint16_t), 0x13, 0, 0);
 			if (hdr->length < 0x1b)
 				break;
 			dmi_str_check(fw, table, addr, "Manufacturer", hdr, 0x17);
@@ -1645,12 +1671,13 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0x1c)
 				break;
 			dmi_reserved_bits_check(fw, table, addr, "Attributes", hdr, sizeof(uint8_t), 0x1b, 4, 7);
-			if (hdr->length < 0x20)
+			if (hdr->length < 0x22)
 				break;
 			dmi_reserved_bits_check(fw, table, addr, "Extended Size", hdr, sizeof(uint32_t), 0x1c, 31, 31);
 			if (hdr->length < 0x4c)
 				break;
 			dmi_min_max_uint8_check(fw, table, addr, "Memory Technology", hdr, 0x28, 0x1, 0x7);
+			dmi_reserved_bits_check(fw, table, addr, "Memory Operating Mode Cap", hdr, sizeof(uint16_t), 0x29, 0, 0);
 			dmi_reserved_bits_check(fw, table, addr, "Memory Operating Mode Cap", hdr, sizeof(uint16_t), 0x29, 6, 15);
 			dmi_str_check(fw, table, addr, "Firmware Version", hdr, 0x2b);
 			if (hdr->length < 0x54)
@@ -1724,7 +1751,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0x07)
 				break;
 			dmi_min_max_uint8_check(fw, table, addr, "Type", hdr, 0x4, 0x1, 0x9);
-			fwts_dmi_value_range t21_ranges[] = {{0x1, 0x8}, {0xa0, 0xa2}};
+			fwts_dmi_value_range t21_ranges[] = {{0x1, 0x8}, {0xa0, 0xa4}};
 			dmi_ranges_uint8_check(fw, table, addr, "Interface", hdr, 0x5, t21_ranges);
 			break;
 
@@ -1952,7 +1979,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0xb)
 				break;
 			dmi_str_check(fw, table, addr, "Reference Designation", hdr, 0x4);
-			dmi_min_max_mask_uint8_check(fw, table, addr, "Device Type", hdr, 0x5, 0x1, 0xa, 0, 0x7f);
+			dmi_min_max_mask_uint8_check(fw, table, addr, "Device Type", hdr, 0x5, 0x1, 0x10, 0, 0x7f);
 			break;
 
 		case 42: /* 7.43 */
@@ -1984,7 +2011,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0x6)
 				break;
 
-			dmi_min_max_uint8_check(fw, table, addr, "IProcessor Architecture Types", hdr, 0x7, 0x0, 0x8);
+			dmi_min_max_uint8_check(fw, table, addr, "IProcessor Architecture Types", hdr, 0x7, 0x0, 0xa);
 			break;
 
 		case 45: /* 7.46 */
