@@ -23,5 +23,6 @@
 #include "fwts.h"
 
 void fwts_dump_raw_data(char *buffer, const size_t len, const uint8_t *data, const int where, const size_t bytes);
-
+void fwts_dump_raw_data_prefix(char *buffer, const size_t len, const uint8_t *data, const char *prefix, const size_t bytes);
+void fwts_hexdump_data_prefix_all(fwts_framework *fw, const uint8_t *data, const char *prefix,	const size_t nbytes);
 #endif
