@@ -113,14 +113,18 @@ enum {
 #define ESRT_FW_TYPE_DEVICEFIRMWARE	0x00000002
 #define ESRT_FW_TYPE_UEFIDRIVER		0x00000003
 
-#define LAST_ATTEMPT_STATUS_SUCCESS			0x00000000
-#define LAST_ATTEMPT_STATUS_ERR_UNSUCCESSFUL		0x00000001
-#define LAST_ATTEMPT_STATUS_ERR_INSUFFICIENT_RESOURCES	0x00000002
-#define LAST_ATTEMPT_STATUS_ERR_INCORRECT_VERSION	0x00000003
-#define LAST_ATTEMPT_STATUS_ERR_INVALID_FORMAT		0x00000004
-#define LAST_ATTEMPT_STATUS_ERR_AUTH_ERROR		0x00000005
-#define LAST_ATTEMPT_STATUS_ERR_PWR_EVT_AC		0x00000006
-#define LAST_ATTEMPT_STATUS_ERR_PWR_EVT_BATT		0x00000007
+#define LAST_ATTEMPT_STATUS_SUCCESS				0x00000000
+#define LAST_ATTEMPT_STATUS_ERR_UNSUCCESSFUL			0x00000001
+#define LAST_ATTEMPT_STATUS_ERR_INSUFFICIENT_RESOURCES		0x00000002
+#define LAST_ATTEMPT_STATUS_ERR_INCORRECT_VERSION		0x00000003
+#define LAST_ATTEMPT_STATUS_ERR_INVALID_FORMAT			0x00000004
+#define LAST_ATTEMPT_STATUS_ERR_AUTH_ERROR			0x00000005
+#define LAST_ATTEMPT_STATUS_ERR_PWR_EVT_AC			0x00000006
+#define LAST_ATTEMPT_STATUS_ERR_PWR_EVT_BATT			0x00000007
+#define LAST_ATTEMPT_STATUS_ERR_UNSATISFIED_DEPENDENCIES	0x00000008
+#define LAST_ATTEMPT_STATUS_ERR_UNSUCCESSFUL_VENDOR_RANGE_MIN	0x00001000
+#define LAST_ATTEMPT_STATUS_ERR_UNSUCCESSFUL_VENDOR_RANGE_MAX	0x00004000
+
 
 #define EFI_RT_SUPPORTED_GET_TIME			0x0001
 #define EFI_RT_SUPPORTED_SET_TIME			0x0002
