@@ -265,9 +265,24 @@ static const acpi_eval_error errors[] = {
 		"The length of an ACPI Resource Descriptor was incorrect."
 	},
 	{ AE_AML_ILLEGAL_ADDRESS, 	LOG_LEVEL_CRITICAL,	"AEAMLIllegalAddr",	"Illegal address",
-		"An memory, PCI configuration or I/O address was encountered with an illegal address."
+		"A memory, PCI configuration or I/O address was encountered with an illegal address."
+	},
+	/* { AE_AML_INFINITE_LOOP, 	LOG_LEVEL_HIGH,		"AEAMLInfiniteLoop",	"Infinite loop", NULL },
+	{ AE_AML_INFINITE_LOOP, 	LOG_LEVEL_HIGH,		"AEAMLInfiniteLoop",	"Infinite loop",
+		"An AML While loop exceeded the maximum execution time."
+	}, */
+	{ AE_AML_UNINITIALIZED_NODE, 	LOG_LEVEL_HIGH,		"AEAMLUninitNode",	"Uninitialized node",
+		"A namespace node is uninitialized or unresolved."
+	},
+	{ AE_AML_TARGET_TYPE,		LOG_LEVEL_HIGH,		"AEAMLTargetType",	"Target type",
+		"A target operand of an incorrect type was encountered."
+	},
+	{ AE_AML_PROTOCOL,		LOG_LEVEL_HIGH,		"AEAMLViolateProtocol",	"Violattion protcol",
+		"Violation of a fixed ACPI protocol."
+	},
+	{ AE_AML_BUFFER_LENGTH, 	LOG_LEVEL_HIGH,		"AEAMLBadBufLength",	"Bad buffer length",
+		"The length of the buffer is invalid/incorrect."
 	},
-	/* { AE_AML_INFINITE_LOOP, 	LOG_LEVEL_HIGH,		"AEAMLInfiniteLoop",	"Infinite loop", NULL }, */
 	{ 0,				0,			NULL,			NULL , 		NULL}
 };
 
@@ -2602,7 +2617,7 @@ void fwts_method_test_NIH_return(
 	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_BUFFER) != FWTS_OK)
 		return;
 
-	if (fwts_method_buffer_size(fw, name, obj, 64) != FWTS_OK)
+	if (fwts_method_buffer_size(fw, name, obj, 4) != FWTS_OK)
 		passed = false;
 
 	ret = (nih_return_t *) obj->Buffer.Pointer;
