@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2022 Canonical
+ * Copyright (C) 2010-2023 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1601,7 +1601,7 @@ void fwts_acpi_reserved_type(
 		fwts_failed(fw, LOG_LEVEL_HIGH, label,
 			"%4.4s must have subtable with Type %" PRId8
 			"..%" PRId8 ", got %" PRId8 " instead",
-			table, min, reserved, value);
+			table, min, reserved - 1, value);
 
 		*passed = false;
 	}
