@@ -69,6 +69,7 @@ static const fwts_categories categories[] = {
 	{ "Interactive Experimental",	FWTS_FLAG_INTERACTIVE_EXPERIMENTAL },
 	{ "Power States",		FWTS_FLAG_POWER_STATES },
 	{ "SBBR",			FWTS_FLAG_SBBR },
+	{ "EBBR",			FWTS_FLAG_EBBR },
 	{ "Utilities",			FWTS_FLAG_UTILS },
 	{ "Unsafe",			FWTS_FLAG_UNSAFE },
 	{ "UEFI",			FWTS_FLAG_UEFI },
@@ -138,7 +139,7 @@ static fwts_option fwts_framework_options[] = {
 	{ "sbbr",		"",   0, "Run ARM SBBR tests." },
 	{ "ifv",		"",   0, "Run tests in firmware-vendor modes." },
 	{ "clog",		"",   1, "Specify a coreboot logfile dump" },
-	{ "ebbr",		"",   0, "Run ARM EBBR tests." },
+	{ "ebbr",		"",   0, "Run EBBR tests." },
 	{ NULL, NULL, 0, NULL }
 };
 
@@ -1350,7 +1351,7 @@ int fwts_framework_options_handler(fwts_framework *fw, int argc, char * const ar
 			fwts_framework_strdup(&fw->clog, optarg);
 			break;
 		case 49: /* --ebbr */
-#if defined(FWTS_ARCH_AARCH64)
+#if defined(FWTS_ARCH_AARCH64) || defined(FWTS_ARCH_RISCV)
 			fw->flags |= FWTS_FLAG_EBBR;
 			break;
 #else
